==> snipe-it-7.1.17.zip: snipe-it-7.1.17/resources/lang/sk-SK/admin/custom_fields/general.php <==
<?php

return [
    'custom_fields'		        => 'Vlastné polia',
    'manage'                    => 'Spravovať',
    'field'		                => 'Pole',
    'about_fieldsets_title'		=> 'O skupinách polí',
    'about_fieldsets_text'		=> 'Skupina polí umožňuje vytvoriť skupinu vlastných polí ktoré sú často prepoužívané pre špecifické typy modelov majetku.',
    'custom_format'             => 'Vlastný formát regexu...',
    'encrypt_field'      	        => 'Zašifrovať hodnotu tohto poľa v databáze',
    'encrypt_field_help'      => 'VAROVANIE: Šifrované pole bude nevyhľadateľné.',
    'encrypted'      	        => 'Šifrované',
    'fieldset'      	        => 'Skupina polí',
    'qty_fields'      	      => 'Počet polí',
    'fieldsets'      	        => 'Skupiny polí',
    'fieldset_name'           => 'Názov skupiny polí',
    'field_name'              => 'Názov poľa',
    'field_values'            => 'Hodnota poľa',
    'field_values_help'       => 'Pridať možnosť výberu, jedna možnosť na riadok. Prázdne riadky okrem prvého riadku budu ignorované.',
    'field_element'           => 'Typ pola',
    'field_element_short'     => 'Pole',
    'field_format'            => 'Formát',
    'field_custom_format'     => 'Vlastný formát regexu',
    'field_custom_format_help'     => 'Toto pole umožňuje použitie regulárneho výrazu pre validáciu. Musí začínať s "regex:" - napríklad pre validáciu, že vlastné pole obsahuje validný IMEI (15 znakov dlhé číslo), je potrebné zadať <code>regex:/^[0-9]{15}$/</code>.',
    'required'   		          => 'Povinné',
    'req'   		              => 'Pov.',
    'used_by_models'   		    => 'Použíte v modeloch',
    'order'   		            => 'Poradie',
    'create_fieldset'         => 'Pridať skupinu polí',
    'update_fieldset'         => 'Upraviť skupinu polí',
    'fieldset_does_not_exist'   => 'Skupina polí :id neexistuje',
    'fieldset_updated'         => 'Skupina polí bola upravená',
    'create_fieldset_title' => 'Vytvoriť novú skupinu polí',
    'create_field'            => 'Nové vlastné pole',
    'create_field_title' => 'Vytvoriť nové vlastné pole',
    'value_encrypted'      	        => 'Hodnota tohto poľa je v databáze šifrovaná. Iba admin používatelia budú schopní dešiforvať jeho hodnotu',
    'show_in_email'     => 'Zahrnúť hodnotu tohto poľa do emailu o priradení posielaného používateľom? Šifrované polia nemôžu byť použíté v mailoch',
    'show_in_email_short'     => 'Zahnúť do mailu.',
    'help_text' => 'Text nápovedy',
    'help_text_description' => 'Toto je voliteľný text, ktorý sa zobrazí pod prvkami formuláru pri editovaní majetku pre poskytnutie kontextu k vypĺňanému polu.',
    'about_custom_fields_title' => 'O vlastných poliach',
    'about_custom_fields_text' => 'Vlastné polia umožňujú pridať povinné atribúty k majetku.',
    'add_field_to_fieldset' => 'Pridať pole do skupiny polí',
    'make_optional' => 'Povinné - kliknite pre nastavenie ako voliteľné',
    'make_required' => 'Voliteľné - kliknitete pre nastavenie ako povinné',
    'reorder' => 'Preusporiadať',
    'db_field' => 'DB pole',
    'db_convert_warning' => 'VÝSTRAHA. Toto pole je v tabuľke vlastných polí ako <code>:db_column</code>, ale malo by byť <code>:expected</code>.',
    'is_unique' => 'Táto hodnota musí byť unikátna naprieč všetkými majetkami',
    'unique' => 'Unikátne',
    'display_in_user_view' => 'Umožni používateľom vidieť tieto hodnoty v prehľade priradných majetkov',
    'display_in_user_view_table' => 'Viditeľné pre používateľa',
    'auto_add_to_fieldsets' => 'Automaticky pridať do každej novej skupiny polí',
    'add_to_preexisting_fieldsets' => 'Pridať do všetkých existujúcich skupín polí',
    'show_in_listview' => 'Zobrazovať v zoznamoch. Autorizovaní používatelia si hodnotu budú môcť aj naďalej skryť cez výber zobrazovaných stĺpcov',
    'show_in_listview_short' => 'Zobraziť v zoznamoch',
    'show_in_requestable_list_short' => 'Zobraziť v zozname vyžiadateľných majetkov',
    'show_in_requestable_list' => 'Zobraziť hodnotu v zoznamu vyžiadateľných majetkov. Šifrované polia nebudu zobratené',
    'encrypted_options' => 'Toto pole je šifrované, takže niektoré možnosti zobrazenia nebudú k dispozícii.',

];

==> snipe-it-8.0.1.zip: snipe-it-8.0.1/resources/lang/sk-SK/admin/custom_fields/general.php <==
<?php

return [
    'custom_fields'		        => 'Vlastné polia',
    'manage'                    => 'Spravovať',
    'field'		                => 'Pole',
    'about_fieldsets_title'		=> 'O skupinách polí',
    'about_fieldsets_text'		=> 'Skupina polí umožňuje vytvoriť skupinu vlastných polí ktoré sú často prepoužívané pre špecifické typy modelov majetku.',
    'custom_format'             => 'Vlastný formát regexu...',
    'encrypt_field'      	        => 'Zašifrovať hodnotu tohto poľa v databáze',
    'encrypt_field_help'      => 'VAROVANIE: Šifrované pole bude nevyhľadateľné.',
    'encrypted'      	        => 'Šifrované',
    'fieldset'      	        => 'Skupina polí',
    'qty_fields'      	      => 'Počet polí',
    'fieldsets'      	        => 'Skupiny polí',
    'fieldset_name'           => 'Názov skupiny polí',
    'field_name'              => 'Názov poľa',
    'field_values'            => 'Hodnota poľa',
    'field_values_help'       => 'Pridať možnosť výberu, jedna možnosť na riadok. Prázdne riadky okrem prvého riadku budu ignorované.',
    'field_element'           => 'Typ pola',
    'field_element_short'     => 'Pole',
    'field_format'            => 'Formát',
    'field_custom_format'     => 'Vlastný formát regexu',
    'field_custom_format_help'     => 'Toto pole umožňuje použitie regulárneho výrazu pre validáciu. Musí začínať s "regex:" - napríklad pre validáciu, že vlastné pole obsahuje validný IMEI (15 znakov dlhé číslo), je potrebné zadať <code>regex:/^[0-9]{15}$/</code>.',
    'required'   		          => 'Povinné',
    'req'   		              => 'Pov.',
    'used_by_models'   		    => 'Použíte v modeloch',
    'order'   		            => 'Poradie',
    'create_fieldset'         => 'Pridať skupinu polí',
    'update_fieldset'         => 'Upraviť skupinu polí',
    'fieldset_does_not_exist'   => 'Skupina polí :id neexistuje',
    'fieldset_updated'         => 'Skupina polí bola upravená',
    'create_fieldset_title' => 'Vytvoriť novú skupinu polí',
    'create_field'            => 'Nové vlastné pole',
    'create_field_title' => 'Vytvoriť nové vlastné pole',
    'value_encrypted'      	        => 'Hodnota tohto poľa je v databáze šifrovaná. Iba admin používatelia budú schopní dešiforvať jeho hodnotu',
    'show_in_email'     => 'Zahrnúť hodnotu tohto poľa do emailu o priradení posielaného používateľom? Šifrované polia nemôžu byť použíté v mailoch',
    'show_in_email_short' => 'Zahnúť do mailu',
    'help_text' => 'Text nápovedy',
    'help_text_description' => 'Toto je voliteľný text, ktorý sa zobrazí pod prvkami formuláru pri editovaní majetku pre poskytnutie kontextu k vypĺňanému polu.',
    'about_custom_fields_title' => 'O vlastných poliach',
    'about_custom_fields_text' => 'Vlastné polia umožňujú pridať povinné atribúty k majetku.',
    'add_field_to_fieldset' => 'Pridať pole do skupiny polí',
    'make_optional' => 'Povinné - kliknite pre nastavenie ako voliteľné',
    'make_required' => 'Voliteľné - kliknitete pre nastavenie ako povinné',
    'reorder' => 'Preusporiadať',
    'db_field' => 'DB pole',
    'db_convert_warning' => 'VÝSTRAHA. Toto pole je v tabuľke vlastných polí ako <code>:db_column</code>, ale malo by byť <code>:expected</code>.',
    'is_unique' => 'Táto hodnota musí byť unikátna naprieč všetkými majetkami',
    'unique' => 'Unikátne',
    'display_in_user_view' => 'Umožni používateľom vidieť tieto hodnoty v prehľade priradných majetkov',
    'display_in_user_view_table' => 'Viditeľné pre používateľa',
    'auto_add_to_fieldsets' => 'Automaticky pridať do každej novej skupiny polí',
    'add_to_preexisting_fieldsets' => 'Pridať do všetkých existujúcich skupín polí',
    'show_in_listview' => 'Zobrazovať v zoznamoch. Autorizovaní používatelia si hodnotu budú môcť aj naďalej skryť cez výber zobrazovaných stĺpcov',
    'show_in_listview_short' => 'Zobraziť v zoznamoch',
    'show_in_requestable_list_short' => 'Zobraziť v zozname vyžiadateľných majetkov',
    'show_in_requestable_list' => 'Zobraziť hodnotu v zoznamu vyžiadateľných majetkov. Šifrované polia nebudu zobratené',
    'encrypted_options' => 'Toto pole je šifrované, takže niektoré možnosti zobrazenia nebudú k dispozícii.',
    'display_checkin' => 'Display in checkin forms',
    'display_checkout' => 'Display in checkout forms',

];
